|Build Status| |codecov.io| |Code Climate|

.. |Build Status| image:: https://travis-ci.org/vfxGer/pretty-numbers.svg?branch=master
   :target: https://travis-ci.org/vfxGer/pretty-numbers
.. |codecov.io| image:: https://codecov.io/gh/vfxGer/pretty-numbers/coverage.svg?branch=master
   :target: https://codecov.io/gh/vfxGer/pretty-numbers
.. |Code Climate| image:: https://codeclimate.com/github/vfxGer/pretty-numbers/badges/gpa.svg
   :target: https://codeclimate.com/github/vfxGer/pretty-numbers
 
